Fixed a bug that was introduced in the last module loader refactoring. The
result was that class path classes were being exposed to bundles.


git-svn-id: https://svn.apache.org/repos/asf/incubator/felix/trunk@391565 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/org.apache.felix.framework/src/main/java/org/apache/felix/framework/searchpolicy/R4SearchPolicyCore.java b/org.apache.felix.framework/src/main/java/org/apache/felix/framework/searchpolicy/R4SearchPolicyCore.java
index 74f0919..83f57dc 100755
--- a/org.apache.felix.framework/src/main/java/org/apache/felix/framework/searchpolicy/R4SearchPolicyCore.java
+++ b/org.apache.felix.framework/src/main/java/org/apache/felix/framework/searchpolicy/R4SearchPolicyCore.java
@@ -372,10 +372,13 @@
         // Start from 1 to skip security manager class.
         for (int i = 1; i < classes.length; i++)
         {
-            // Find the first class on the call stack that is neither
-            // a class loader or Class itself, because we want to ignore
-            // the calls to ClassLoader.loadClass() and Class.forName().
-            if (!ClassLoader.class.isAssignableFrom(classes[i]) &&
+            // Find the first class on the call stack that is not one
+            // of the R4 search policy classes, nor a class loader or
+            // class itself, because we want to ignore the calls to
+            // ClassLoader.loadClass() and Class.forName().
+            if (!R4SearchPolicyCore.class.equals(classes[i]) &&
+                !R4SearchPolicy.class.equals(classes[i]) &&
+                !ClassLoader.class.isAssignableFrom(classes[i]) &&
                 !Class.class.isAssignableFrom(classes[i]))
             {
                 // If the instigating class was not from a bundle, then
@@ -523,10 +526,13 @@
         // Start from 1 to skip security manager class.
         for (int i = 1; i < classes.length; i++)
         {
-            // Find the first class on the call stack that is neither
-            // a class loader or Class itself, because we want to ignore
-            // the calls to ClassLoader.loadClass() and Class.forName().
-            if (!ClassLoader.class.isAssignableFrom(classes[i]) &&
+            // Find the first class on the call stack that is not one
+            // of the R4 search policy classes, nor a class loader or
+            // class itself, because we want to ignore the calls to
+            // ClassLoader.loadClass() and Class.forName().
+            if (!R4SearchPolicyCore.class.equals(classes[i]) &&
+                !R4SearchPolicy.class.equals(classes[i]) &&
+                !ClassLoader.class.isAssignableFrom(classes[i]) &&
                 !Class.class.isAssignableFrom(classes[i]))
             {
                 // If the instigating class was not from a bundle, then